clear
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Compare a technology shock
% in a world with sticky prices and sticky wages
% relative to a world with flex prices and wages
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

dynare sticky    % model with sticky prices and wages
save simulation0 dr_ ys_ lgy_ lgx_

dynare growthmodel    % model with flex prices and wages
save simulation1 dr_ ys_ lgy_ lgx_


% number of periods for IRFs.
nperiods = 20;

%%%% Make figure to compare simulation 0 and 1
load simulation0 
shock = [0
         0.01];
dset = 'f0';        
makeirf

load simulation1
shock = [0
         0.01];
dset = 'f1';        
makeirf

titlelist = char('Output','Capital (next period)','Investment','Labor','Consumption','Marginal Cost');
legendlist = char('Sticky Prices','Flex Prices');
figlabel = 'Responses to a 1% increase in productivity';
makechart(titlelist,legendlist,figlabel,...
          100*[f0_gdp_irf/f0_gdp, f0_kp_irf/f0_kp, f0_ip_irf/f0_ip, f0_le_irf/f0_le, f0_cc_irf/f0_cc, f0_sigma_irf/f0_sigma],...
          100*[f1_gdp_irf/f1_gdp, f1_kp_irf/f1_kp, f1_ip_irf/f1_ip, f1_le_irf/f1_le, f1_cc_irf/f1_cc, 0*f0_sigma_irf/f0_sigma])


titlelist = char('Marginal Cost','Real Wage','Marginal Product of Labor','Rental Rate of Capital');
legendlist = char('Sticky Prices');
figlabel = 'Responses to a 1% increase in productivity';
makechart(titlelist,legendlist,figlabel,...
          100*[ f0_sigma_irf/f0_sigma, f0_zeta_irf/f0_zeta, f0_zeta_irf/f0_zeta-f0_sigma_irf/f0_sigma, f0_rk_irf/f0_rk],...
          100*[ nan*f0_sigma_irf/f0_sigma, f1_rw_irf/f1_rw, f1_rw_irf/f1_rw, f1_rk_irf/f1_rk])        
      
titlelist = char('Inflation (AR)','Nominal Interest Rate (AR)','Real Ex-ante Rate (AR)');
legendlist = char('Sticky Prices/Wages');
figlabel = 'Responses to a 1% increase in productivity';
makechart(titlelist,legendlist,figlabel,...
          100*[ f0_dp_irf*4, f0_rs_irf*4, f0_rs1_irf*4])
