// RBC model 
// with variable labor

var cc, le, lambda, gamma, gdp, ip ,kp, rw, rk, n, m;
varexo nerr, merr;

// %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
// % define parameters here
// %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

parameters beta_p, chi_p, le_p, delta_p, el, theta_p, 
           kpshr_p, nu_p, s_p, chi0_p, rhon_p, rhom_p;


// Discount factor  (default .99)
beta_p = 0.99;

// Frisch Elasticity of labor supply (2/chi_p);
chi_p = 10;

// Steady state labor supply
le_p = 1/3;

// depreciation rate (default 0.025)
delta_p = 0.025;

// elasticity of substitution between capital and labor
el = 1;
theta_p = 1;
 

// Set nu so as to hit desired capital share
nu_p = 0.3

// rental rate for capital in ss
rk_p = 1/beta_p -1 +delta_p;

// saving rate
s_p = (nu_p/rk_p)^(1/theta_p)*(delta_p);  

// wage rate in ss
zeta_p = (1-nu_p)*(nu_p/rk_p)^(nu_p/(1-nu_p));

// gdp in ss
gdp_p = (nu_p/rk_p)^(nu_p/(1-nu_p))*le_p;

// cc in ss
cc_p = (1-s_p)*gdp_p;

// lambda in ss
lambda_p = 1/cc_p;

// parameter determining labor supply in SS
chi0_p = (1-le_p)^chi_p * lambda_p * zeta_p

rhon_p = 0.95;    
rhom_p = 0.95;
     
  
model;


// FOC with respect to consumption
1/cc - lambda=0;   

// FOC wrt Labor
-chi0_p*(1-le)^(-chi_p) + lambda * rw =0;

// Lambda Marginal Utility of consumption
gamma-lambda = 0;

// gamma shadow price of capital
(1-delta_p)*beta_p * gamma(1) - gamma +beta_p *lambda(1)*rk(1) = 0;

// Aggregate Output
//gdp = (nu_p*(kp(-1)*exp(m))^(1-theta_p) + (le*exp(n))^(1-theta_p))^(1/(1-theta_p));
//switch over if theta_p =1
gdp = (kp(-1)*exp(m))^nu_p*(exp(n)*le)^(1-nu_p);

// Resource constraint
gdp = cc + ip;

// Capital
kp = (1-delta_p)*kp(-1) + ip;

// Rental Rate for Labor, FOC with respect to labor
rw = (1-nu_p)*(gdp/(le*exp(n)))^(theta_p)*exp(n);

// Rental Rate for Capital
rk = nu_p*(gdp/(kp(-1)*exp(m)))^theta_p * exp(m);

// Labor-augmenting technology shock
n = rhon_p*n(-1) + nerr;

// Capital Augmenting Technology Shock
m = rhom_p*m(-1) + merr;

end;


// Steady state values

initval;

// Labor
le = le_p;

// Output
//gdp = le_p*(1-nu_p*(s_p/(delta_p))^(1-theta_p))^(1/(theta_p-1));
// switch to this if theta_p = 1
gdp = (s_p/delta_p)^(nu_p/(1-nu_p))*le_p;

// Investment
ip = (s_p * gdp);

// Consumption
cc = (gdp - ip);

// Capital 
kp = ip/delta_p;

// Rental rate for capital
rk = (delta_p - 1 + 1/beta_p);

// Rental rate for labor
rw = (1-nu_p)*(gdp/le)^theta_p;

// Marginal utility of consumption
lambda = 1/cc;

// GAMMA: Marginal utility of capital
gamma = lambda;

// Labor-augmenting technology
n=0;

// Capital-augmenting technology
m=0;

end;

shocks;
var nerr; stderr .01;
var merr; stderr .01;
end;

check;


stoch_simul(order=1,nocorr,nomoments,irf=0);

//stoch_simul(order=1,nocorr,nomoments,noprint,irf=0);
