// RBC model 
// with variable labor

var cc, le, lambda, q, gdp, ip ,kp, zeta, rk, n, m, sigma, dp, dw, rs, wmarkup, rs1,
    ccpot, lepot, lambdapot, gammapot, gdppot, ippot, kppot, zetapot, rkpot, gdpgap;

varexo nerr, merr;

// %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
// % define parameters here
// %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

parameters alpha_p, kappap_p, kappaw_p, beta_p, chi_p, le_p, 
           psik_p, psii_p, delta_p, theta_p, rs_rsl_p, rs_dp_p, rs_gdp_p, rs_gdpgap_p, 
           kpshr_p, nu_p, s_p, chi0_p, rhon_p, rhom_p, gdp_p,
           wmarkup_p, dw_p, dp_p, zeta_p, lambda_p, sigma_p;


// Discount factor  (default .99)
beta_p = 0.99;

// Frisch Elasticity of labor supply (2/chi_p);
chi_p = 10;

// Steady state labor supply
le_p = 1/3;

// depreciation rate (default 0.025)
delta_p = 0.025;

// investment adjustment costs
psik_p = 0;

// capital adjustment costs
psii_p = 0;

// Capital's share of income
alpha_p = 0.3;

// paramters in the interest rate reaction function 
rs_rsl_p = 0;
rs_dp_p = 1000;
rs_gdp_p = 0;
rs_gdpgap_p = 0;

// probability that an intermediate firm will not be allowed to renew its price
xip_p = 0.75

// probability that a household will reset its wage
xiw_p = 0.75;

// wage markup
thetaw_p = 0.1;

// coefficient on marginal cost in inflation equation
kappap_p = (1-beta_p*xip_p)*(1-xip_p)/xip_p;

// coefficient on mrs in the wage inflation equation
kappaw_p = (1-beta_p*xiw_p)*(1-xiw_p)/xiw_p /( 1 + chi_p*le_p/(1-le_p)*(1+thetaw_p)/thetaw_p )
//kappaw_p = (1-beta_p*xiw_p)*(1-xiw_p)/xiw_p /( 1 + chi_p*(1+thetaw_p)/thetaw_p )

// marginal cost in steady state
// set production subsidies so as to ensure this.
sigma_p = 1;

// inflation in ss
dp_p = 1;

// wage inflation in ss
dw_p =1;

// rental rate for capital in ss
rk_p = 1/beta_p -1 +delta_p;

// wage rate in ss
zeta_p = (1-alpha_p)*(alpha_p/rk_p)^(alpha_p/(1-alpha_p));

// saving rate in ss
s_p = (alpha_p/rk_p)*(delta_p);  

// gdp in ss
gdp_p = (alpha_p/rk_p)^(alpha_p/(1-alpha_p))*le_p;

// cc in ss
cc_p = (1-s_p)*gdp_p;

// lambda in ss
lambda_p = 1/cc_p;

// parameter determining labor supply in SS
chi0_p = (1-le_p)^chi_p * lambda_p * zeta_p

// wmarkup
wmarkup_p = (((1-le_p)^(-chi_p))/lambda_p) / zeta_p

// persistence parameters
rhon_p = 0.95;    
rhom_p = 0.95;
     


model;

// 1. FOC with respect to consumption
1/cc - lambda=0;   

// 2. FOC wrt Labor
zeta/zeta(-1)=dw/dp;

// 3. FOC for investment
q = 1 + psik_p*(ip/kp(-1) - delta_p) + psii_p *(ip/ip(-1)-1) 
    -  psii_p * dp(1)/(1+rs) * (ip(1)/ip-1) 
    -  psii_p/2 * dp(1)/(1+rs) * (ip(1)/ip-1)^2;

// 4. FOC for capital
q =dp(1)/(1+rs)*( (1-delta_p)*q(1) + rk(1) - psik_p/2*(ip(1)/kp - delta_p)^2 + psik_p*ip(1)/kp(1)*(ip(1)/kp(1)-delta_p));

// 5. wage inflation
log(dw) - log(dw_p) = beta_p*(log(dw(1)) - log(dw_p))+kappaw_p*(log(wmarkup)-log(wmarkup_p));

// 6. wage markup
log(wmarkup)-log(wmarkup_p) = ( chi_p*le_p/(1-le_p)*(log(le)-log(le_p))-(log(lambda)-log(lambda_p))
                          -(log(zeta)-log(zeta_p)) );

// 7. Capital
kp = (1-delta_p)*kp(-1) + ip;

// 8. price inflation
log(dp)-log(dp_p) = beta_p * (log(dp(1))-log(dp_p)) + kappap_p*(log(sigma)-log(sigma_p));

// 9. interest rate reaction function
rs =  (- 1 + 1/ beta_p ) 
	      +  rs_rsl_p *(rs(-1) - (- 1 + 1/beta_p ) ) 
	      +  rs_dp_p * (dp -dp_p)
	      +  rs_gdp_p * (log(gdp)- log(gdp(-1)))
          +  rs_gdpgap_p * (log(gdpgap));

// 10. Rental Rate for Labor, FOC with respect to labor
sigma = zeta/((1-alpha_p)*gdp/le);

// 11. Rental Rate for Capital
sigma = rk/(alpha_p*gdp/kp(-1));

// 12. Aggregate Output
gdp = (kp(-1)*exp(m))^(alpha_p)*(le*exp(n))^(1-alpha_p);

// 13. Resource constraint
gdp = cc + ip;

// 14. FOC with respect to bond holding
dp(1)/(1+rs) = beta_p * lambda(1)/lambda;

// 15. Ex-ante real rate
rs1 = (1+rs)/dp(1)-1;

// 15. Labor-augmenting technology shock
n = rhon_p*n(-1) + nerr;

// 16. Capital Augmenting Technology Shock
m = rhom_p*m(-1) + merr;


/////////////////////////////////////////////////
// parallel model with no rigidities 
// used to compute potential output
// this part of the model does not incorporate
// real rigidities
/////////////////////////////////////////////////

// 17. FOC with respect to consumption
1/ccpot - lambdapot=0;   

// 18. FOC wrt Labor
-chi0_p*(1-lepot)^(-chi_p) + lambdapot * zetapot =0;

// 19. Lambda Marginal Utility of consumption
gammapot-lambdapot = 0;

// 20. gamma shadow price of capital
(1-delta_p)*beta_p * gammapot(1) - gammapot +beta_p *lambdapot(1)*rkpot(1) = 0;

// 21. Aggregate Output
gdppot = (kppot(-1)*exp(m))^alpha_p*(exp(n)*lepot)^(1-alpha_p);

// 22. Resource constraint
gdppot = ccpot + ippot;

// 23. Capital
kppot = (1-delta_p)*kppot(-1) + ippot;

// 24. Rental Rate for Labor, FOC with respect to labor
zetapot = (1-alpha_p)*(gdppot/(lepot*exp(n)))*exp(n);

// 25. Rental Rate for Capital
rkpot = alpha_p*(gdppot/(kppot(-1)*exp(m))) * exp(m);

// 26. GDP Gap
gdpgap = gdp/gdppot;

end;


// Steady state values

initval;

// marginal cost
sigma = 1;

// Labor
le = le_p;

// Inflation
dp = dp_p;

// Wage Inflation
dw = dw_p;

// Output
gdp = gdp_p;

// Investment
ip = (s_p * gdp);

// Consumption
cc = (gdp - ip);

// Capital 
kp = ip/delta_p;

// Rental rate for capital
rk = rk_p;

// Rental rate for labor
zeta = zeta_p;

// Marginal utility of consumption
lambda = lambda_p;

// Nominal interest rate
rs = 1/beta_p -1;

// Real ex-ante rate
rs1 = 1/beta_p -1;

// Tobin's Q
q = 1;

// wmarkup
wmarkup = wmarkup_p;

// Labor-augmenting technology
n=0;

// Capital-augmenting technology
m=0;

// variables from potential output part of the model
ccpot = cc;
lepot=le;
lambdapot=lambda;
gammapot=lambda;
gdppot = gdp;
ippot = ip;
kppot = kp;
zetapot = zeta;
rkpot = rk;
gdpgap = 1;

end;

shocks;
var nerr; stderr .01;
var merr; stderr .01;
end;

check;


stoch_simul(order=1,nocorr,nomoments,irf=0);

//stoch_simul(order=1,nocorr,nomoments,noprint,irf=0);
